@@ -13,6 +13,7 @@
 #------------------------------------------------------------------------------
 """ A group of action manager items. """
 
+from functools import partial
 
 # Enthought library imports.
 from traits.api import Any, Bool, HasTraits, Instance, List, Property
@@ -50,7 +51,7 @@ class Group(HasTraits):
     items = Property
 
     #: The action manager that the group belongs to.
-    parent = Any#Instance('pyface.action.ActionManager')
+    parent = Any  #Instance('pyface.action.ActionManager')
 
     #: Does this group require a separator when it is visualized?
     separator = Bool(True)
@@ -58,13 +59,13 @@ class Group(HasTraits):
     #### Private interface ####
 
     #: All of the items in the group.
-    _items = List#(ActionManagerItem)
+    _items = List  #(ActionManagerItem)
 
     ###########################################################################
     # 'object' interface.
     ###########################################################################
 
-    def __init__(self, *items,  **traits):
+    def __init__(self, *items, **traits):
         """ Creates a new menu manager.
 
         Parameters
@@ -249,6 +250,15 @@ class Group(HasTraits):
         else:
             return None
 
+    @classmethod
+    def factory(cls, *args, **kwargs):
+        """ Create a factory for a group with the given arguments.
+
+        This is particularly useful for passing context to Tasks schema
+        additions.
+        """
+        return partial(cls, *args, **kwargs)
+
 
 class Separator(Group):
     """ A convenience class.
