@@ -16,7 +16,7 @@ class EditorAreaPaneTestCase(unittest.TestCase):
         """
         area = EditorAreaPane()
         area.register_factory(Editor, lambda obj: isinstance(obj, int))
-        self.assertTrue(isinstance(area.create_editor(0), Editor))
+        self.assert_(isinstance(area.create_editor(0), Editor))
 
     @unittest.skipIf(USING_WX, "EditorAreaPane is not implemented in WX")
     def test_factories(self):
