@@ -1,8 +1,7 @@
-
+from __future__ import absolute_import
 
 import os
-
-from traits.testing.unittest_tools import unittest
+import unittest
 
 from ..image_cache import ImageCache
 
