@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 
-from traits.testing.unittest_tools import unittest
+import unittest
 
 from ..heading_text import HeadingText
 from ..split_dialog import SplitDialog
