@@ -9,9 +9,7 @@
 
 # Standard library imports.
 import sys
-
-if sys.version_info[0] > 2:
-    str = str
+import six
 
 # Major library imports.
 from pyface.qt import QtCore, QtGui, qt_api
@@ -35,7 +33,7 @@ class SplitTabWidget(QtGui.QSplitter):
     # The different hotspots of a QTabWidget.  An non-negative value is a tab
     # index and the hotspot is to the left of it.
 
-    tabTextChanged = QtCore.Signal(QtGui.QWidget, str)
+    tabTextChanged = QtCore.Signal(QtGui.QWidget, six.text_type)
     _HS_NONE = -1
     _HS_AFTER_LAST_TAB = -2
     _HS_NORTH = -3
@@ -95,8 +93,8 @@ class SplitTabWidget(QtGui.QSplitter):
                 for t in range(ch.count()):
                     # A tab state is a tuple of the widget's object name and
                     # the title.
-                    name = str(ch.widget(t).objectName())
-                    title = str(ch.tabText(t))
+                    name = six.text_type(ch.widget(t).objectName())
+                    title = six.text_type(ch.tabText(t))
 
                     tab_states.append((name, title))
 
@@ -711,12 +709,12 @@ class SplitTabWidget(QtGui.QSplitter):
                 h = rect.height()
                 if top_bottom:
                     tab_widths = sum(tab_bar.tabRect(i).width()
-                        for i in list(range(tab_bar.count())))
+                        for i in range(tab_bar.count()))
                     w -= tab_widths
                     gx += tab_widths
                 else:
                     tab_heights = sum(tab_bar.tabRect(i).height()
-                        for i in list(range(tab_bar.count())))
+                        for i in range(tab_bar.count()))
                     h -= tab_heights
                     gy -= tab_heights
                 return (tw, self._HS_AFTER_LAST_TAB, (gx, gy, w, h))
@@ -977,7 +975,7 @@ class _DragableTabBar(QtGui.QTabBar):
     def _setCurrentTabText(self):
         idx = self.currentIndex()
         text = self._title_edit.text()
-        self.setTabText(idx, '\u25b6'+text)
+        self.setTabText(idx, u'\u25b6'+text)
         self._root.tabTextChanged.emit(self.parent().widget(idx), text)
 
     def _resize_title_edit_to_current_tab(self):
