@@ -1,6 +1,4 @@
-#------------------------------------------------------------------------------
-#
-#  Copyright (c) 2005, Enthought, Inc.
+#  Copyright (c) 2005-19, Enthought, Inc.
 #  All rights reserved.
 #
 #  This software is provided without warranty under the terms of the BSD
@@ -11,14 +9,17 @@
 #  Thanks for using Enthought open source!
 #
 #  Author: Enthought, Inc.
-#
-#------------------------------------------------------------------------------
 
 """ The wx specific implementations the action manager internal classes.
 """
 
 # Standard libary imports.
-from inspect import getargspec
+import six
+if six.PY2:
+    from inspect import getargspec
+else:
+    # avoid deprecation warning
+    from inspect import getfullargspec as getargspec
 
 # Major package imports.
 import wx
@@ -33,7 +34,8 @@ from pyface.action.action_event import ActionEvent
 _STYLE_TO_KIND_MAP = {
     'push'   : wx.ITEM_NORMAL,
     'radio'  : wx.ITEM_RADIO,
-    'toggle' : wx.ITEM_CHECK
+    'toggle' : wx.ITEM_CHECK,
+    'widget' : None,
 }
 
 
@@ -76,6 +78,10 @@ class _MenuItem(HasTraits):
         kind    = _STYLE_TO_KIND_MAP[action.style]
         longtip = action.description or action.tooltip
 
+        if action.style == "widget":
+            raise NotImplementedError(
+                "WxPython does not support widgets in menus")
+
         if len(action.accelerator) > 0:
             label = label + '\t' + action.accelerator
 
@@ -266,11 +272,11 @@ class _MenuItem(HasTraits):
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it. This is also
             # useful as Traits UI controllers *never* require the event.
-            args, varargs, varkw, dflts = getargspec(self.controller.perform)
+            argspec = getargspec(self.controller.perform)
 
             # If the only arguments are 'self' and 'action' then don't pass
             # the event!
-            if len(args) == 2:
+            if len(argspec.args) == 2:
                 self.controller.perform(action)
 
             else:
@@ -283,10 +289,10 @@ class _MenuItem(HasTraits):
             # Most of the time, action's do no care about the event (it
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it.
-            args, varargs, varkw, dflts = getargspec(action.perform)
+            argspec = getargspec(action.perform)
 
             # If the only argument is 'self' then don't pass the event!
-            if len(args) == 1:
+            if len(argspec.args) == 1:
                 action.perform()
 
             else:
@@ -362,27 +368,32 @@ class _Tool(HasTraits):
         else:
             self.tool_bar.SetSize((-1, 50))
 
-        self.control_id = wx.NewId()
-        self.control = tool_bar.AddLabelTool(
-            self.control_id, label, bmp, wx.NullBitmap, kind, tooltip, longtip, None
-        )
-
-        # Set the initial checked state.
-        tool_bar.ToggleTool(self.control_id, action.checked)
-
-        if hasattr(tool_bar, 'ShowTool'):
-            # Set the initial enabled/disabled state of the action.
-            tool_bar.EnableTool(self.control_id, action.enabled)
-
-            # Set the initial visibility
-            tool_bar.ShowTool(self.control_id, action.visible)
+        if action.style == 'widget':
+            widget = action.create_control(self.tool_bar)
+            self.control = tool_bar.AddControl(widget, label)
+            self.control_id = self.control.GetId()
         else:
-            # Set the initial enabled/disabled state of the action.
-            tool_bar.EnableTool(
-                self.control_id, action.enabled and action.visible)
+            self.control_id = wx.NewId()
+            self.control = tool_bar.AddLabelTool(
+                self.control_id, label, bmp, wx.NullBitmap, kind, tooltip, longtip, None
+            )
 
-        # Wire it up.
-        wx.EVT_TOOL(parent, self.control_id, self._on_tool)
+            # Set the initial checked state.
+            tool_bar.ToggleTool(self.control_id, action.checked)
+
+            if hasattr(tool_bar, 'ShowTool'):
+                # Set the initial enabled/disabled state of the action.
+                tool_bar.EnableTool(self.control_id, action.enabled)
+
+                # Set the initial visibility
+                tool_bar.ShowTool(self.control_id, action.visible)
+            else:
+                # Set the initial enabled/disabled state of the action.
+                tool_bar.EnableTool(
+                    self.control_id, action.enabled and action.visible)
+
+            # Wire it up.
+            wx.EVT_TOOL(parent, self.control_id, self._on_tool)
 
         # Listen for trait changes on the action (so that we can update its
         # enabled/disabled/checked state etc).
@@ -496,11 +507,11 @@ class _Tool(HasTraits):
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it. This is also
             # useful as Traits UI controllers *never* require the event.
-            args, varargs, varkw, dflts = getargspec(self.controller.perform)
+            argspec = getargspec(self.controller.perform)
 
             # If the only arguments are 'self' and 'action' then don't pass
             # the event!
-            if len(args) == 2:
+            if len(argspec.args) == 2:
                 self.controller.perform(action)
 
             else:
@@ -512,10 +523,10 @@ class _Tool(HasTraits):
             # Most of the time, action's do no care about the event (it
             # contains information about the time the event occurred etc), so
             # we only pass it if the perform method requires it.
-            args, varargs, varkw, dflts = getargspec(action.perform)
+            argspec = getargspec(action.perform)
 
             # If the only argument is 'self' then don't pass the event!
-            if len(args) == 1:
+            if len(argspec.args) == 1:
                 action.perform()
 
             else:
@@ -546,6 +557,10 @@ class _PaletteTool(HasTraits):
         action = self.item.action
         label = action.name
 
+        if action.style == "widget":
+            raise NotImplementedError(
+                "WxPython does not support widgets in palettes")
+
         # Tool palette tools never have '...' at the end.
         if label.endswith('...'):
             label = label[:-3]
